@@ -1,5 +1,4 @@
 import subprocess
-import os
 from typing import List
 
 import click
@@ -36,13 +35,14 @@ def umm(start: bool, stop: bool, add: bool, tags: List[str]):
         return
     if start:
         print("umm server starting")
-        os.environ["UMM_RUNNING"] = 1
         main()
         return
     if stop:
         print("umm server stopping")
         import psutil
+
         from umm.utils.config import parse_config
+
         config = parse_config()
 
         # find and kill pid(s)
@@ -56,13 +56,13 @@ def umm(start: bool, stop: bool, add: bool, tags: List[str]):
                             pids.add(proc.pid)
         for pid in pids:
             subprocess.run(["kill", f"{pid}"])
-        
-        # if pids were found
-        if pids:
-            os.environ["UMM_RUNNING"] = 0
-        else:
+
+        # if no pids were found
+        if not pids:
             print("Could not find running server")
 
+        return
+
     try:
         candidates = umm_request(tags)
     except requests.exceptions.ConnectionError:
